==> msxpertsuite_5.3.3.orig.tar.gz: msxpertsuite-5.3.3/massxpert/gui/CalculatorRecorderDlg.hpp <==
/* BEGIN software license
 *
 * msXpertSuite - mass spectrometry software suite
 * -----------------------------------------------
 * Copyright(C) 2009,...,2018 Filippo Rusconi
 *
 * http://www.msxpertsuite.org
 *
 * This file is part of the msXpertSuite project.
 *
 * The msXpertSuite project is the successor of the massXpert project. This
 * project now includes various independent modules:
 *
 * - massXpert, model polymer chemistries and simulate mass spectrometric data;
 * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * END software license
 */




#ifndef CALCULATOR_RECORDER_DLG_HPP
#define CALCULATOR_RECORDER_DLG_HPP


/////////////////////// Qt includes


/////////////////////// Local includes
#include <ui_CalculatorRecorderDlg.h>


namespace msXpSmassXpert
{

  class CalculatorRecorderDlg : public QDialog
  {
    Q_OBJECT

    private:
    Ui::CalculatorRecorderDlg m_ui;

    public:
    CalculatorRecorderDlg(QWidget *      parent,
                          const QString &configSettingsFilePath);

    ~CalculatorRecorderDlg();

    QString m_configSettingsFilePath;

    void record(const QString &);

    public slots:
    void close();
  };

} // namespace msXpSmassXpert


#endif // CALCULATOR_RECORDER_DLG_HPP

==> msxpertsuite_5.8.6.orig.tar.gz: msxpertsuite-5.8.6/massxpert/gui/CalculatorRecorderDlg.hpp <==
/* BEGIN software license
 *
 * msXpertSuite - mass spectrometry software suite
 * -----------------------------------------------
 * Copyright(C) 2009,...,2018 Filippo Rusconi
 *
 * http://www.msxpertsuite.org
 *
 * This file is part of the msXpertSuite project.
 *
 * The msXpertSuite project is the successor of the massXpert project. This
 * project now includes various independent modules:
 *
 * - massXpert, model polymer chemistries and simulate mass spectrometric data;
 * - mineXpert, a powerful TIC chromatogram/mass spectrum viewer/miner;
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 *
 * END software license
 */


#ifndef CALCULATOR_RECORDER_DLG_HPP
#define CALCULATOR_RECORDER_DLG_HPP


/////////////////////// Qt includes


/////////////////////// Local includes
#include <ui_CalculatorRecorderDlg.h>


namespace msXpSmassXpert
{

class CalculatorRecorderDlg : public QDialog
{
  Q_OBJECT

  private:
  Ui::CalculatorRecorderDlg m_ui;

  public:
  CalculatorRecorderDlg(QWidget *parent, const QString &configSettingsFilePath);

  ~CalculatorRecorderDlg();

  QString m_configSettingsFilePath;

  void record(const QString &);

  public slots:
  void close();
};

} // namespace msXpSmassXpert


#endif // CALCULATOR_RECORDER_DLG_HPP
